@@ -2,12 +2,12 @@
  * 
  * util.c
  *
- * copyright (c) 2001-9, Karl W Broman and Hao Wu
+ * copyright (c) 2001-2010, Karl W Broman and Hao Wu
  *
  * This file written mostly by Karl Broman with some additions
  * from Hao Wu.
  *
- * last modified Apr, 2009
+ * last modified Feb, 2010
  * first written Feb, 2001
  *
  *     This program is free software; you can redistribute it and/or
@@ -39,15 +39,9 @@
  *
  **********************************************************************/
 
-#include <math.h>
-#include <stdlib.h>
-#include <stdio.h>
 #include <R.h>
-#include <Rmath.h>
-#include <R_ext/PrtUtil.h>
-#include <R_ext/Utils.h>
+/* #include <R_ext/BLAS.h> */
 #include "util.h"
-#include <R_ext/Lapack.h>
 
 #define THRESH 200.0
 
@@ -534,23 +528,33 @@ void R_comparegeno(int *geno, int *n_ind, int *n_mar,
   
 void R_locate_xo(int *n_ind, int *n_mar, int *type,
 		 int *geno, double *map, 
-		 double *location, int *nseen)
+		 double *location, int *nseen,
+		 int *ileft, int *iright, double *left, double *right,
+		 int *full_info)
 {
-  int **Geno;
-  double **Location;
+  int **Geno, **iLeft, **iRight;
+  double **Location, **Left, **Right;
 
   reorg_geno(*n_ind, *n_mar, geno, &Geno);
   reorg_errlod(*n_ind, (*type+1)*(*n_mar-1), location, &Location);
+  if(*full_info) {
+    reorg_errlod(*n_ind, (*type+1)*(*n_mar-1), left, &Left);
+    reorg_errlod(*n_ind, (*type+1)*(*n_mar-1), right, &Right);
+    reorg_geno(*n_ind, (*type+1)*(*n_mar-1), ileft, &iLeft);
+    reorg_geno(*n_ind, (*type+1)*(*n_mar-1), iright, &iRight);
+  }
 
   locate_xo(*n_ind, *n_mar, *type, Geno, map, Location,
-	   nseen);
+	    nseen, iLeft, iRight, Left, Right, *full_info);
 }
 
 /* Note: type ==0 for backcross and ==1 for intercross */
 void locate_xo(int n_ind, int n_mar, int type, int **Geno,
-	       double *map, double **Location, int *nseen)
+	       double *map, double **Location, int *nseen,
+	       int **iLeft, int **iRight, double **Left, double **Right,
+	       int full_info)
 {
-  int i, j, curgen, number;
+  int i, j, curgen, number, icurpos;
   double curpos;
 
   for(i=0; i<n_ind; i++) {
@@ -558,11 +562,13 @@ void locate_xo(int n_ind, int n_mar, int type, int **Geno,
 
     curgen = Geno[0][i];
     curpos = map[0];
+    icurpos = 0;
     nseen[i]=0;
     for(j=1; j<n_mar; j++) {
       if(curgen==0) { /* haven't yet seen a genotype */
 	curgen = Geno[j][i];
 	curpos = map[j];
+	icurpos = j;
       }
       else {
 	if(Geno[j][i] == 0) { /* not typed */
@@ -570,13 +576,22 @@ void locate_xo(int n_ind, int n_mar, int type, int **Geno,
 	else {
 	  if(Geno[j][i] == curgen) {
 	    curpos = map[j];
+	    icurpos = j;
 	  }
 	  else {
 	    if(type==0) {
 	      Location[nseen[i]][i] = (map[j]+curpos)/2.0;
 
+	      if(full_info) {
+		Left[nseen[i]][i] = curpos;
+		Right[nseen[i]][i] = map[j];
+		iLeft[nseen[i]][i] = icurpos+1;
+		iRight[nseen[i]][i] = j+1;
+	      }
+
 	      curgen = Geno[j][i];
 	      curpos = map[j];
+	      icurpos=j;
 	      nseen[i]++;
 	    }
 	    else {
@@ -621,14 +636,27 @@ void locate_xo(int n_ind, int n_mar, int type, int **Geno,
 	      
 	      if(number==1) {
 		Location[nseen[i]][i] = (curpos+map[j])/2.0;
+		if(full_info) {
+		  Left[nseen[i]][i] = curpos;
+		  Right[nseen[i]][i] = map[j];
+		  iLeft[nseen[i]][i] = icurpos+1;
+		  iRight[nseen[i]][i] = j+1;
+		}
 		nseen[i]++;
 	      }
-	      else if(number==2) {
+	      else if(number==2) { /* two crossovers in interval: place 1/3 and 2/3 along */
 		Location[nseen[i]][i] = (curpos+2.0*map[j])/3.0;
 		Location[nseen[i]+1][i] = (2.0*curpos+map[j])/3.0;
+		if(full_info) {
+		  Left[nseen[i]][i] = Left[nseen[i]+1][i] = curpos; 
+		  Right[nseen[i]][i] = Right[nseen[i]+1][i] = map[j];
+		  iLeft[nseen[i]][i] = iLeft[nseen[i]+1][i] = icurpos+1; 
+		  iRight[nseen[i]][i] = iRight[nseen[i]+1][i] = j+1;
+		}
 		nseen[i] += 2;
 	      }
 	      curpos = map[j];
+	      icurpos = j;
 	    }
 	  }
 	}
@@ -638,6 +666,7 @@ void locate_xo(int n_ind, int n_mar, int type, int **Geno,
 }
 	  
 /* multiply two matrices - I'm using dgemm from lapack here */
+/*
 void matmult2(double *result, double *a, int nrowa,
              int ncola, double *b, int ncolb)
 
@@ -646,6 +675,7 @@ void matmult2(double *result, double *a, int nrowa,
   F77_CALL(dgemm)("N", "N", &nrowa, &ncolb, &ncola, &alpha, a, &nrowa,
              b, &ncola, &beta, result, &nrowa);
 }
+*/
 
 void matmult(double *result, double *a, int nrowa,
              int ncola, double *b, int ncolb)
@@ -815,5 +845,4 @@ void R_reviseMWril(int *n_ril, int *n_mar, int *n_str,
 	      *missingval);
 }
 
-/* end of util.c */
 
